Crate kwaak

Crate kwaak 

Modules

agent
chat
chat_message
cli
commands
Kwaak uses a command pattern to handle the backend asynchroniously.
config
frontend
git
This module contains git and github related utilities
indexing
kwaak_tracing
onboarding
This modules provides the onboarding flow for Kwaak.
repository
runtime_settings
Runtime settings are persisted settings that are used to configure the behavior of the application at runtime.
templates
test_utils
util

Macros

assert_agent_responded
assert_command_done
Run the UI until a certain event is reached