DelegateAgent

Struct DelegateAgent 

pub struct DelegateAgent { /* private fields */ }
A tool that delegates to an agent

For convenience, its assumed the agent is already set up (a RunningAgent).

The tool takes a tool spec, agent and session during creating, so that it can be utilized to delegate to any agent.

After delegation, the agent invoking the tool is stopped, but not destroyed.

Implementations

Source

impl DelegateAgent

pub fn builder() -> DelegateAgentBuilder

pub async fn delegate_agent( &self, _context: &dyn AgentContext, task: &str, ) -> Result<ToolOutput, ToolError>