Modules
- agent
- chat
- chat_
message - cli
- commands
- Kwaak uses a command pattern to handle the backend asynchroniously.
- config
- frontend
- git
- This module contains git and github related utilities
- indexing
- kwaak_
tracing - onboarding
- This modules provides the onboarding flow for Kwaak.
- repository
- runtime_
settings - Runtime settings are persisted settings that are used to configure the behavior of the application at runtime.
- templates
- test_
utils - util
Macros
- assert_
agent_ responded - assert_
command_ done - Run the UI until a certain event is reached